@@ -78,8 +78,7 @@ impl Reply for LightSpeedError {
             }
             LightSpeedError::RepositoryError { .. } => {
                 let http_code = http::StatusCode::BAD_REQUEST;
-                let error_details =
-                    reply::json(&WebErrorDetails::from_message(http_code.as_u16(), &None));
+                let error_details = reply::json(&WebErrorDetails::from_message(http_code.as_u16(), &None));
                 reply::with_status(error_details, http_code).into_response()
             }
             LightSpeedError::RequestConflict { code, .. } => {
@@ -97,7 +96,9 @@ impl Reply for LightSpeedError {
             LightSpeedError::ModuleBuilderError { .. }
             | LightSpeedError::ModuleStartError { .. }
             | LightSpeedError::ConfigurationError { .. }
-            | LightSpeedError::PasswordEncryptionError { .. } => http::StatusCode::INTERNAL_SERVER_ERROR.into_response(),
+            | LightSpeedError::PasswordEncryptionError { .. } => {
+                http::StatusCode::INTERNAL_SERVER_ERROR.into_response()
+            }
         }
     }
 }
